# Pisek ⏳

Tool for developing tasks for programming competitions.

## Installation

Pisek requires Python 3.11 or newer. You can install it with pip:
```bash
pip install pisek
```

## Usage

You can create a task skeleton with:
```bash
pisek init
```

Test the task in the current directory with: 
```bash
pisek test
```

## Docs

See our [user documentation](https://piskoviste.github.io/pisek/) for more details.
